package com.ruoyi.frequency.mallspecifications.service;

import java.util.List;
import com.ruoyi.frequency.mallspecifications.entity.MallSpecifications;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 单规格规格Service接口
 * 
 * @author liwenlong
 * @date 2024-01-25
 */
public interface MallSpecificationsService extends IService<MallSpecifications>
{
    /**
     * 查询单规格规格
     * 
     * @param id 单规格规格主键
     * @return 单规格规格
     */
    public MallSpecifications selectMallSpecificationsById(Long id);

    /**
     * 查询单规格规格列表
     * 
     * @param mallSpecifications 单规格规格
     * @return 单规格规格集合
     */
    public List<MallSpecifications> selectMallSpecificationsList(MallSpecifications mallSpecifications);

    /**
     * 新增单规格规格
     * 
     * @param mallSpecifications 单规格规格
     * @return 结果
     */
    public int insertMallSpecifications(MallSpecifications mallSpecifications);

    /**
     * 修改单规格规格
     * 
     * @param mallSpecifications 单规格规格
     * @return 结果
     */
    public int updateMallSpecifications(MallSpecifications mallSpecifications);

    /**
     * 批量删除单规格规格
     * 
     * @param ids 需要删除的单规格规格主键集合
     * @return 结果
     */
    public int deleteMallSpecificationsByIds(Long[] ids,Integer delFlag);

}
